#include "Cube.h"


/* Constructor - just calls the generate function */
Cube::Cube()
{
  xpos = 0;
  ypos = 0;
  zpos = 0;
  rotation = 0;
  rotate = true;

  generateCube();
}

/* Constructor that accepts an initial location as a parameter. */
Cube::Cube(GLfloat x, GLfloat y, GLfloat z)
{
  xpos = x;
  ypos = y;
  zpos = z;
  rotation = 0;
  rotate = true;

  generateCube();
}

Cube::~Cube()
{}

/* Creates the cube and puts it into a GL call list
 * for quick access.
 */
void Cube::generateCube()
{
  // Set the lighting values.
  float white[] = {1,1,1,1};
  float black[] = {0,0,0,1};
  float shinyvec[] = {128};
  glMaterialfv(GL_FRONT_AND_BACK,GL_SHININESS,shinyvec);
  glMaterialfv(GL_FRONT_AND_BACK,GL_SPECULAR,white);
  glMaterialfv(GL_FRONT_AND_BACK,GL_EMISSION,black);

  // Start recording for the call list
  cube = glGenLists(1);
  glNewList(cube,GL_COMPILE);

  // Side 1 - Magenta
  glColor3f(1,0,1);
  glBegin(GL_QUADS);
  glNormal3f(0,0,-1);
  glVertex3f(1,1,-1);
  glVertex3f(1,-1,-1);
  glVertex3f(-1,-1,-1);
  glVertex3f(-1,1,-1);
  glEnd();

  // Side 2 - Red
  glColor3f(1,0,0);
  glBegin(GL_QUADS);
  glNormal3f(1,0,0);
  glVertex3f(1,1,1);
  glVertex3f(1,-1,1);
  glVertex3f(1,-1,-1);
  glVertex3f(1,1,-1);
  glEnd();

  // Side 3 - Green
  glColor3f(0,1,0);
  glBegin(GL_QUADS);
  glNormal3f(-1,0,0);
  glVertex3f(-1,1,1);
  glVertex3f(-1,-1,1);
  glVertex3f(-1,-1,-1);
  glVertex3f(-1,1,-1);
  glEnd();

  // Side 4 - Blue
  glColor3f(0,0,1);
  glBegin(GL_QUADS);
  glNormal3f(0,1,0);
  glVertex3f(1,1,1);
  glVertex3f(1,1,-1);
  glVertex3f(-1,1,-1);
  glVertex3f(-1,1,1);
  glEnd();

  // Side 5 - Cyan
  glColor3f(0,1,1);
  glBegin(GL_QUADS);
  glNormal3f(0,-1,0);
  glVertex3f(1,-1,1);
  glVertex3f(1,-1,-1);
  glVertex3f(-1,-1,-1);
  glVertex3f(-1,-1,1);
  glEnd();

  // Side 6 - Yellow
  glColor3f(1,1,0);
  glBegin(GL_QUADS);
  glNormal3f(0,0,1);
  glVertex3f(1,1,1);
  glVertex3f(1,-1,1);
  glVertex3f(-1,-1,1);
  glVertex3f(-1,1,1);
  glEnd();

  glEndList();
}

/* Since our generation function did all the hard
 * work, all we have to do is locate and call the
 * call list we created.
 */
void Cube::draw()
{
  if (rotate)
    rotation -=5;
  glPushMatrix();
  glTranslated(xpos,ypos,zpos);
  glRotated(rotation,0,0,1);
  glCallList(cube);
  glPopMatrix();
}